@@ -9,7 +9,7 @@ use File::Spec();
 
 my $SEP = File::Spec->catfile('', '');
 
-our $VERSION = '0.000017';
+our $VERSION = '0.000018';
 
 # Directly modifying this is a bad idea, but for the XS to work it needs to be
 # a package var, not a lexical.
@@ -17,6 +17,7 @@ our $FROM = '*';
 my $FROM_MODIFIED = 0;
 my $FROM_MANAGER;
 
+my $ROOT;
 
 my %REPORT;
 our @TOUCHED;
@@ -40,8 +41,9 @@ sub import {
     }
 
     my $ran = 0;
-    my $root = path('.')->realpath;
-    my $callback = sub { return if $ran++; $class->report(%params, ctx => $_[0], root => $root) };
+    $ROOT = $params{root} if $params{root};
+    $ROOT //= path('.')->realpath;
+    my $callback = sub { return if $ran++; $class->report(%params, ctx => $_[0], root => $ROOT) };
 
     test2_add_callback_exit($callback);
 
@@ -66,6 +68,8 @@ sub reset_coverage {
     %REPORT  = ();
 }
 
+sub set_root { $ROOT = pop };
+
 sub get_from   { $FROM }
 sub set_from   { $FROM_MODIFIED++; $FROM = pop }
 sub clear_from { $FROM = '*' }
